@@ -14,7 +14,7 @@ from json import loads
 from xapian import Query, QueryParser, UnimplementedError, DocNotFoundError
 
 from . import snowball
-from .exc import ValidationError
+from .exc import ValidationError, PrefixError
 
 
 RETRY_LIMIT = 3
@@ -268,9 +268,15 @@ class Database(object):
             else:
                 self.add_prefix(name, upped)
 
-    def add_prefix(self, key, value):
+    def add_prefix(self, key, value, ignore_duplicates=True):
         """Add a prefix mapping to the database.
         """
+        if key in self.boolean_prefixes:
+            if ignore_duplicates:
+                logger.warning('Conflicting relevance prefix %s', key)
+                return
+            else:
+                raise PrefixError('Conflicting relevance prefix %s', key)
         self.relevance_prefixes[key] = value
         self.backend.set_metadata(self.relevance_prefix + key, value)
 
@@ -559,12 +565,17 @@ class Database(object):
         qp.set_database(self.backend)
         qp.set_default_op(default_op)
 
-        if self.relevance_prefixes:
-            for key, value in self.relevance_prefixes.items():
-                qp.add_prefix(key, value)
         if self.boolean_prefixes:
             for key, value in self.boolean_prefixes.items():
                 qp.add_boolean_prefix(key, value)
+        if self.relevance_prefixes:
+            for key, value in self.relevance_prefixes.items():
+                if key not in self.boolean_prefixes:
+                    qp.add_prefix(key, value)
+                else:
+                    logger.warning(
+                        'Duplicate relevance prefix %s conflicts with boolean',
+                        key)
         if self.value_sorts:
             # First add numeric values ranges
             qp.add_valuerangeprocessor(MultipleValueRangeProcessor(
